@@ -51,7 +51,7 @@ class Device:
                 async with session.get(self._url('/v1/state/')) as response:
                     return await response.json()
 
-    async def set_state(self, state, **kwargs):
+    async def set_state(self, state={}, **kwargs):
         """
         Set the state of the device from a raw state dict.
 
@@ -67,6 +67,8 @@ class Device:
         hsv = kwargs.pop('hsv', None)
         period = kwargs.pop('period', None)
         easing = kwargs.pop('easing', None)
+        fire_cooling = kwargs.pop('fire_cooling', None)
+        fire_sparking = kwargs.pop('fire_sparking', None)
 
         if hsv is not None:
             kwargs["hue"], kwargs["saturation"], kwargs["value"] = hsv
